@@ -23,6 +23,13 @@
 #define SQUASH_PLAY_MP3_H
 
 #include <mad.h>    /* MP3 Decoder */
+#ifndef NO_ID3LIB
+    #ifndef NO_NCURSES
+        #undef bool         /* make id3lib play with ncurses, let's hope that doesn't
+                             * come back and haunt us. */
+    #endif
+    #include <id3.h>    /* id3lib to read tags */
+#endif
 
 /*
  * Structures
@@ -35,7 +42,6 @@ typedef struct mp3_data_s {
     struct mad_frame frame;
     struct mad_synth synth;
     mad_timer_t timer;
-    long duration;
     char *pcm_data;
 } mp3_data_t;
 
@@ -43,9 +49,10 @@ typedef struct mp3_data_s {
  * Prototypes
  */
 void *mp3_open( char *filename, sound_format_t *sound_format );
+void mp3_load_meta( void *data, char *filename );
 frame_data_t mp3_decode_frame( void *data );
 long mp3_calc_duration( void *data );
-void mp3_seek( void *data, long seek_time );
+void mp3_seek( void *data, long seek_time, long duration );
 void mp3_close( void *data );
 unsigned int mad_to_16bit( mad_fixed_t f );
 
